@@ -213,7 +213,7 @@ class BaseSqlHelper(abc.ABC):
         :return:
         """
         if desc is None:
-            raise BusinessException(StatusCode.MESSAGE_FORMAT(StatusCode.INTERNAL_SERVER_ERROR, "没有需要解析的结果集"))
+            raise BusinessException(StatusCode.INTERNAL_SERVER_ERROR("没有需要解析的结果集"))
         titles = [c[0] for c in desc]
         if isinstance(values, list):
             return [dict(zip(titles, value)) for value in values]
