@@ -90,11 +90,9 @@ class ElasticsearchHelper(BaseSqlHelper):
         :param condition_wrapper:  查询条件信息
         :return:
         """
-        db_str, collection_str = condition_wrapper.table.split(".")
-        db = self.pool[db_str]
-        collection = db[collection_str]
+        table_str = condition_wrapper.table
         aggregate = self.prepare_query_sql(condition_wrapper)
-        return await self.execute_fetchone(aggregate, {"collection": collection})
+        return await self.execute_fetchone(table_str, aggregate.get("$match", []))
 
     async def fetchall_data(self, condition_wrapper: ConditionWrapper):
         """
@@ -132,17 +130,39 @@ class ElasticsearchHelper(BaseSqlHelper):
         return Page(records=records, current=page_num, page_size=page_size, total=total.get("count", 0)).__dict__
 
     @echo_sql
-    async def execute_fetchone(self, sql: str, param=None):
+    async def execute_fetchone(self, param=None, sql: list = [], column: list = [], aes_enable=True, aes_key=None):
         """
         查询单条数据
+        :param aes_key: aes密钥
+        :param aes_enable: 是否开启aes加密
+        :param column: 返回的字段
         :param sql: 待执行的Sql语句
-        :param param: 参数
+        :param param: 表名
         :return:
         """
-        cursor = param["collection"].aggregate(sql)
-        rs = await cursor.to_list(1)
-        if len(rs) > 0:
-            return rs[0]
+
+        body = {
+            "query": {
+                "bool": {
+                    "must": sql
+                }
+            }
+        }
+        resp = await self.pool.search(
+            index=param,
+            body=body,
+            _source_includes=column
+        )
+        hits = resp.get("hits", {}).get("hits", [])
+        if hits:
+            info = hits[0].get("_source", {})
+            info.update({"_id": hits[0].get("_id")})
+            if aes_enable:
+                key = "haohaoxuexi"
+                if aes_key:
+                    key = aes_key
+                info["_id"] = AES.encrypt(key, info.get("_id"))
+            return info
         return None
 
     @echo_sql
@@ -334,21 +354,21 @@ class ElasticsearchHelper(BaseSqlHelper):
         :param conditions: 条件信息
         :return: 条件sql片段, values 对应参数
         """
-        connector = "$and"
+        operators = ["AND"]
         if len(conditions) == 0:
             return {}
         filter_item = []
-        current_filter_items = {"bool": {"must": []}}
+        first_filter_items = {"bool": {"must": []}}
         for condition in conditions:
             # 获取当前过滤条件
             operator, column, value = condition
-            if operator == "AND" or operator == "OR":
+            if operator in ["OR", "AND"]:
                 if operator == "AND":
-                    # filter_item.append({"bool": {"must": []}})
-                    current_filter_items = {"bool": {"must": []}}
-                else:
-                    # filter_item.append({"bool": {"should": []}})
-                    current_filter_items = {"bool": {"should": []}}
+                    operators.append("AND")
+                    first_filter_items = {"bool": {"must": []}}
+                elif operator == "OR":
+                    operators.append("OR")
+                    first_filter_items = {"bool": {"should": []}}
                 continue
             if operator == "=":
                 condition_item = {"term": {column: value}}
@@ -386,11 +406,13 @@ class ElasticsearchHelper(BaseSqlHelper):
                 condition_item = {"must_not": {"terms": {column: value}}}
             else:
                 continue
-            if operator == "AND":
-                current_filter_items["bool"]["must"].append(condition_item)
+            if operators[-1] == "OR":
+                first_filter_items["bool"]["should"].append(condition_item)
+            elif operators[-1] == "AND":
+                first_filter_items["bool"]["must"].append(condition_item)
             else:
-                current_filter_items["bool"]["should"].append(condition_item)
-        filter_item.append(current_filter_items)
+                continue
+        filter_item.append(first_filter_items)
         logging.debug(f"Elasticsearch Condition:{filter_item}")
         return filter_item
 
